@@ -140,15 +140,14 @@ class StreamProcessor(Generic[TStrategyPayload]):
         commit_policy: CommitPolicy = ONCE_PER_SECOND,
         dlq_policy: Optional[DlqPolicy[TStrategyPayload]] = None,
         join_timeout: Optional[float] = None,
-        shutdown_strategy_before_consumer: bool = False,
     ) -> None:
         self.__consumer = consumer
         self.__processor_factory = processor_factory
         self.__metrics_buffer = MetricsBuffer()
 
-        self.__processing_strategy: Optional[ProcessingStrategy[TStrategyPayload]] = (
-            None
-        )
+        self.__processing_strategy: Optional[
+            ProcessingStrategy[TStrategyPayload]
+        ] = None
 
         self.__message: Optional[BrokerValue[TStrategyPayload]] = None
 
@@ -165,7 +164,6 @@ class StreamProcessor(Generic[TStrategyPayload]):
         )
 
         self.__shutdown_requested = False
-        self.__shutdown_strategy_before_consumer = shutdown_strategy_before_consumer
 
         # Buffers messages for DLQ. Messages are added when they are submitted for processing and
         # removed once the commit callback is fired as they are guaranteed to be valid at that point.
@@ -383,9 +381,12 @@ class StreamProcessor(Generic[TStrategyPayload]):
             start_dlq = time.time()
             invalid_message = self.__buffered_messages.pop(exc.partition, exc.offset)
             if invalid_message is None:
-                raise Exception(
-                    f"Invalid message not found in buffer {exc.partition} {exc.offset}",
-                ) from None
+                logger.error(
+                    "Invalid message not found in buffer %s %s",
+                    exc.partition,
+                    exc.offset,
+                )
+                return
 
             # XXX: This blocks if there are more than MAX_PENDING_FUTURES in the queue.
             try:
@@ -464,40 +465,20 @@ class StreamProcessor(Generic[TStrategyPayload]):
                         self.__is_paused = True
 
                     elif self.__is_paused:
-                        paused_partitions = set(self.__consumer.paused())
-                        all_partitions = set(self.__consumer.tell())
-                        unpaused_partitions = (
-                            all_partitions - paused_partitions
-                        )
-                        if unpaused_partitions:
-                            logger.warning(
-                                "Processor in paused state while consumer is partially unpaused: %s, paused: %s",
-                                unpaused_partitions,
-                                paused_partitions,
-                            )
-                            self.__is_paused = False
-                            # unpause paused partitions... just in case a subset is paused
-                            self.__metrics_buffer.incr_counter(
-                                "arroyo.consumer.resume", 1
-                            )
-                            self.__consumer.resume([*paused_partitions])
-                        else:
-                            # A paused consumer should still poll periodically to avoid it's partitions
-                            # getting revoked by the broker after reaching the max.poll.interval.ms
-                            # Polling a paused consumer should never yield a message.
-                            logger.warning("consumer.tell() value right before poll() is: %s", self.__consumer.tell())
-                            maybe_message = self.__consumer.poll(0.1)
-                            if maybe_message is not None:
-                                logger.warning("Received a message from partition: %s, \
-                                                consumer.tell() value right after poll() is: %s \
-                                                Some lines above consumer.tell() was called, all_partitons value was: %s \
-                                                Some lines above consumer.paused() was called, paused_partitions value is: %s",
-                                                maybe_message.partition,
-                                                self.__consumer.tell(),
-                                                all_partitions,
-                                                paused_partitions
-                                                )
-                            assert maybe_message is None
+                        maybe_message = self.__consumer.poll(0.1)
+                        if maybe_message is not None:
+                            # The paused consumer, in the above poll, has
+                            # gone through rebalancing. In this case we
+                            # expect that partition revocation cleared the
+                            # pause flag and the carried over message.
+                            # this assumption will not hold for cooperative-sticky rebalancing.
+                            assert (
+                                not self.__is_paused
+                            ), "consumer unpaused itself without rebalancing"
+                            assert (
+                                self.__message is None
+                            ), "consumer unpaused itself without rebalancing"
+
                     else:
                         time.sleep(0.01)
 
@@ -538,12 +519,11 @@ class StreamProcessor(Generic[TStrategyPayload]):
         self.__shutdown_requested = True
 
     def _shutdown(self) -> None:
-        # If shutdown_strategy_before_consumer is set, work around an issue
-        # where rdkafka would revoke our partition, but then also immediately
-        # revoke our member ID as well, causing join() of the CommitStrategy
-        # (that is running in the partition revocation callback) to crash.
-        if self.__shutdown_strategy_before_consumer:
-            self._close_processing_strategy()
+        # when we close() a consumer, rdkafka would would revoke our partition
+        # and call revocation callbacks, but also immediately revoke our member
+        # ID as well, causing join() of the CommitStrategy (that is running in
+        # the partition revocation callback) to crash.
+        self._close_processing_strategy()
 
         # close the consumer
         logger.info("Stopping consumer")
